@@ -19,8 +19,8 @@ import gdb
 import os
 import os.path
 
-pythondir = '/builder/ixp4xx_harddisk/build/staging_dir/toolchain-armeb_xscale_gcc-7.3.0_musl/share/gcc-7.3.0/python'
-libdir = '/builder/ixp4xx_harddisk/build/staging_dir/toolchain-armeb_xscale_gcc-7.3.0_musl/armeb-openwrt-linux-muslgnueabi/lib'
+pythondir = '/builder/shared-workdir/build/staging_dir/toolchain-armeb_xscale_gcc-7.3.0_musl/share/gcc-7.3.0/python'
+libdir = '/builder/shared-workdir/build/staging_dir/toolchain-armeb_xscale_gcc-7.3.0_musl/armeb-openwrt-linux-muslgnueabi/lib'
 
 # This file might be loaded when there is no current objfile.  This
 # can happen if the user loads it manually.  In this case we don't
